@@ -17,22 +17,22 @@ class Gallery(DeeplabelBase):
     parent_folder_id:Optional[str]
 
     @classmethod
-    def _from_search_params(cls, params:Dict[str, Any], client: "deeplabel.client.BaseClient") -> List["Gallery"]:
+    def from_search_params(cls, params:Dict[str, Any], client: "deeplabel.client.BaseClient") -> List["Gallery"]:
         resp = client.get("/gallery", params=params)
         galleries = resp.json()["data"]["gallery"]
         galleries = [cls(**gallery, client=client) for gallery in galleries]
-        return galleries
+        return galleries #type: ignore
     
     @classmethod
     def from_gallery_id(cls, gallery_id:str, client: "deeplabel.client.BaseClient")->"Gallery":
-        gallery = cls._from_search_params({"galleryId":gallery_id}, client=client)
+        gallery = cls.from_search_params({"galleryId":gallery_id}, client=client)
         if not len(gallery):
             raise InvalidIdError(f"Failed to fetch video with videoId: {gallery_id}")
         return gallery[0]
     
     @classmethod
     def from_folder_id(cls, folder_id:str, client: "deeplabel.client.BaseClient")-> List["Gallery"]:
-        return cls._from_search_params({"parentFolderId":folder_id}, client)
+        return cls.from_search_params({"parentFolderId":folder_id}, client)
     
     @property
     def images(self)->List['deeplabel.infer.gallery.images.Image']:
